@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Async::Bulk;
-$Search::Elasticsearch::Async::Bulk::VERSION = '2.00';
+$Search::Elasticsearch::Async::Bulk::VERSION = '2.01';
 use Moo;
 with 'Search::Elasticsearch::Role::Bulk',
     'Search::Elasticsearch::Role::Is_Async';
@@ -210,7 +210,7 @@ Search::Elasticsearch::Async::Bulk - A helper module for the Bulk API and for re
 
 =head1 VERSION
 
-version 2.00
+version 2.01
 
 =head1 SYNOPSIS
 
@@ -571,9 +571,7 @@ In this case, all you have to do is to pass in a list of IDs.
           doc_as_upsert => 1
         },
         { id            => 2,
-          lang          => 'mvel',
-          script        => '_ctx.source.counter+=incr',
-          params        => { incr => 1},
+          script        => { script },
           upsert        => { upsert doc }
         },
         ...
@@ -583,7 +581,7 @@ The C<update()> helper method allows you to add multiple C<update> actions.
 It accepts the same parameters as L<Search::Elasticsearch::Client::2_0::Direct/update()>.
 An update can either use a I<partial doc> which gets merged with an existing
 doc (example 1 above), or can use a C<script> to update an existing doc
-(example 2 above).
+(example 2 above). More information on C<script> can be found here: L<Search::Elasticsearch::Client::2_0::Direct/update()>.
 
 =head1 REINDEXING DOCUMENTS
 
@@ -744,7 +742,7 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Elasticsearch BV.
+This software is Copyright (c) 2016 by Elasticsearch BV.
 
 This is free software, licensed under:
 
